/*
 * Name:    d_mdrive.h 
 *
 * Purpose: Header file for MX motor driver to control Intelligent Motion
 *          Systems MDrive motor controllers.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __D_MDRIVE_H__
#define __D_MDRIVE_H__

/* ===== MDrive motor data structures ===== */

#define MXU_MDRIVE_IOSETUP_LENGTH	10

typedef struct {
	MX_RECORD *record;

	MX_RECORD *rs232_record;
	char axis_name;

	int negative_limit_switch;
	int positive_limit_switch;
	int home_switch;

	char s1[ MXU_MDRIVE_IOSETUP_LENGTH + 1 ];
	char s2[ MXU_MDRIVE_IOSETUP_LENGTH + 1 ];
	char s3[ MXU_MDRIVE_IOSETUP_LENGTH + 1 ];
	char s4[ MXU_MDRIVE_IOSETUP_LENGTH + 1 ];
} MX_MDRIVE;

/* Define all of the interface functions. */

MX_API mx_status_type mxd_mdrive_create_record_structures( MX_RECORD *record );
MX_API mx_status_type mxd_mdrive_finish_record_initialization(
					MX_RECORD *record );
MX_API mx_status_type mxd_mdrive_print_motor_structure(
					FILE *file, MX_RECORD *record );
MX_API mx_status_type mxd_mdrive_open( MX_RECORD *record );
MX_API mx_status_type mxd_mdrive_resynchronize( MX_RECORD *record );

MX_API mx_status_type mxd_mdrive_move_absolute( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_get_position( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_set_position( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_soft_abort( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_immediate_abort( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_find_home_position( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_constant_velocity_move( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_get_parameter( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_set_parameter( MX_MOTOR *motor );
MX_API mx_status_type mxd_mdrive_get_status( MX_MOTOR *motor );

extern MX_RECORD_FUNCTION_LIST mxd_mdrive_record_function_list;
extern MX_MOTOR_FUNCTION_LIST mxd_mdrive_motor_function_list;

/* Define some extra functions for the use of this driver. */

MX_API mx_status_type mxd_mdrive_command( MX_MDRIVE *mdrive,char *command,
			char *response, int response_buffer_length,
			int debug_flag );

extern long mxd_mdrive_num_record_fields;
extern MX_RECORD_FIELD_DEFAULTS *mxd_mdrive_rfield_def_ptr;

#define MXD_MDRIVE_STANDARD_FIELDS \
  {-1, -1, "rs232_record", MXFT_RECORD, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, rs232_record), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "axis_name", MXFT_CHAR, NULL, 0, {0}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, axis_name), \
	{0}, NULL, (MXFF_IN_DESCRIPTION | MXFF_IN_SUMMARY)}, \
  \
  {-1, -1, "s1", MXFT_STRING, NULL, 1, {MXU_MDRIVE_IOSETUP_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, s1), \
	{sizeof(char)}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "s2", MXFT_STRING, NULL, 1, {MXU_MDRIVE_IOSETUP_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, s2), \
	{sizeof(char)}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "s3", MXFT_STRING, NULL, 1, {MXU_MDRIVE_IOSETUP_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, s3), \
	{sizeof(char)}, NULL, MXFF_IN_DESCRIPTION}, \
  \
  {-1, -1, "s4", MXFT_STRING, NULL, 1, {MXU_MDRIVE_IOSETUP_LENGTH}, \
	MXF_REC_TYPE_STRUCT, offsetof(MX_MDRIVE, s4), \
	{sizeof(char)}, NULL, MXFF_IN_DESCRIPTION}

#endif /* __D_MDRIVE_H__ */
