/*
 * Name:    mx_epics.h
 *
 * Purpose: Header file for some utilities for using EPICS with MX.
 *
 * Author:  William Lavender
 *
 *----------------------------------------------------------------------
 *
 * Copyright 1999-2003 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MX_EPICS_H__
#define __MX_EPICS_H__

/* The following are include files from the EPICS distribution. */

#if defined(__MX_LIBRARY__)
#   include "tsDefs.h"
#   include "cadef.h"
#   include "ezca.h"
#endif

#define MX_CA_CHAR	0
#define MX_CA_STRING	1
#define MX_CA_SHORT	2
#define MX_CA_LONG	3
#define MX_CA_FLOAT	4
#define MX_CA_DOUBLE	5

MX_API mx_status_type mx_caget_by_name( char *pvname, char ezcatype,
				int num_elements, void *data_buffer );

MX_API mx_status_type mx_caput_by_name( char *pvname, char ezcatype,
				int num_elements, void *data_buffer );

MX_API mx_status_type mx_caput_nowait_by_name( char *pvname, char ezcatype,
				int num_elements, void *data_buffer );

MX_API mx_status_type mx_epics_get_num_elements( char *pvname,
						int *num_elements );

MX_API mx_status_type mx_epics_start_group( void );

MX_API mx_status_type mx_epics_end_group( void );

MX_API int  mx_epics_get_debug_flag( void );

MX_API void mx_epics_set_debug_flag( int value );

MX_API mx_status_type mx_epics_convert_mx_type_to_epics_type(
				long mx_type, chtype *epics_type );

MX_API mx_status_type mx_epics_convert_epics_type_to_mx_type(
				chtype epics_type, long *mx_type );

MX_API mx_status_type mx_epics_convert_mx_type_to_ezca_type(
				long mx_type, char *ezca_type );

MX_API mx_status_type mx_epics_convert_ezca_type_to_mx_type(
				char ezca_type, long *mx_type );

#endif /* __MX_EPICS_H__ */

